@@ -31,6 +31,7 @@ print.gsmvar <- function(x, ..., digits=2, summary_print=FALSE) {
   IC <- gsmvar$IC
   constraints <- gsmvar$model$constraints
   same_means <- gsmvar$model$same_means
+  weight_constraints <- gsmvar$model$weight_constraints
   structural_pars <- gsmvar$model$structural_pars
   all_mu <- round(get_regime_means(gsmvar), digits)
   params <- gsmvar$params
@@ -38,6 +39,7 @@ print.gsmvar <- function(x, ..., digits=2, summary_print=FALSE) {
   T_obs <- ifelse(is.null(gsmvar$data), NA, nrow(gsmvar$data))
   params <- reform_constrained_pars(p=p, M=M, d=d, params=params, model=model,
                                     constraints=constraints, same_means=same_means,
+                                    weight_constraints=weight_constraints,
                                     structural_pars=structural_pars)
   if(gsmvar$model$parametrization == "mean") {
     params <- change_parametrization(p=p, M=M, d=d, params=params, model=model,
@@ -59,13 +61,11 @@ print.gsmvar <- function(x, ..., digits=2, summary_print=FALSE) {
   }
   cat(paste0("d = ", d, ", #parameters = " , npars, ","),
       ifelse(is.na(T_obs), "\n", paste0("#observations = ", T_obs, " x ", d, ",\n")),
-      ifelse(gsmvar$model$conditional, "conditional", "exact"),
-      "log-likelihood,",
-      ifelse(gsmvar$model$parametrization == "mean", "mean parametrization,", "intercept parametrization,"),
-      ifelse(is.null(same_means),
-             ifelse(is.null(constraints), "no AR parameter constraints", "AR parameters constrained"),
-             ifelse(is.null(constraints), "mean paremeters constrained, no AR parameter constraints",
-                                          "mean parameters constrained, AR parameters constrained")), "\n")
+      ifelse(gsmvar$model$conditional, "conditional", "exact"), "log-likelihood,",
+      paste0(ifelse(gsmvar$model$parametrization == "mean", "mean parametrization", "intercept parametrization"),
+             ifelse(is.null(same_means), "", ", mean parameters constrained"),
+             ifelse(is.null(constraints), "", ", AR matrices constrained"),
+             ifelse(is.null(weight_constraints), "", ", alphas constrained")), "\n")
   cat("\n")
 
   if(summary_print) {
@@ -179,8 +179,11 @@ print.gsmvar <- function(x, ..., digits=2, summary_print=FALSE) {
     n_free <- sum(is.na(W_orig))
     n_sign <- d^2 - n_zero - n_free
     cat("The B-matrix (or equally W) is subject to", n_zero, "zero constraints and", n_sign, "sign constraints.\n")
-    cat("The eigenvalues lambda_{mi} are", ifelse(is.null(gsmvar$model$structural_pars$C_lambda), "not subject to linear constraints.",
-                                                  "subject to linear constraints."))
+    cat("The eigenvalues lambda_{mi} are", ifelse(is.null(gsmvar$model$structural_pars$C_lambda),
+                                                  ifelse(is.null(gsmvar$model$structural_pars$fixed_lambdas),
+                                                         "not subject to linear constraints.",
+                                                         "subject to fixed lambda constraints.")
+                                                  , "subject to linear constraints."))
     cat("\n")
   }
 
@@ -412,3 +415,55 @@ print.hypotest <- function(x, ..., digits=4) {
              ", p-value = ", format_value(x$p_value)))
   invisible(x)
 }
+
+
+#' @describeIn linear_IRF print method
+#' @inheritParams print.girf
+#' @param x object of class \code{'irf'} generated by the function \code{linear_IRF}.
+#' @param N_to_print an integer specifying the horizon how far to print the estimates and
+#'   confidence intervals. The default is that all the values are printed.
+#' @param shocks_to_print the responses to which should should be printed?
+#'   A numeric vector with elements in \code{1,...,d}. The default is that responses to
+#'   all the shocks are printed.
+#' @param ... currently not used.
+#' @export
+
+print.irf <- function(x, ..., digits=2, N_to_print, shocks_to_print) {
+  irf <- x
+  point_est <- irf$point_est
+  stopifnot(digits >= 0 & digits%%1 == 0)
+  format_value <- format_valuef(digits)
+  if(missing(N_to_print)) {
+    N_to_print <- dim(point_est)[3] # n slices
+  } else {
+    stopifnot(N_to_print %in% 1:irf$N)
+  }
+  if(missing(shocks_to_print)) {
+    shocks_to_print <- 1:irf$gsmvar$model$d
+  } else {
+    stopifnot(all(shocks_to_print %in% irf$gsmvar$model$d))
+  }
+  var_names <- colnames(irf$gsmvar$data)
+  if(length(irf$which_cumulative) > 0) {
+    cat(paste0("The responses of the variables ",
+               paste0(var_names[irf$which_cumulative], collapse=", "),
+               " were cumulated."), "\n\n")
+  }
+
+  # Loop through the shocks
+  for(i1 in shocks_to_print) {
+    if(i1 > 1) cat("------------------------\n")
+    cat(paste0("The IRF of Shock ", i1, ":"), "\n")
+    irf_i1 <- as.data.frame(format_value(t(point_est[, i1, ]))) # irf[variable, shock, horizon] -> irf_i1[variable, horizon]
+    colnames(irf_i1) <- var_names
+    rownames(irf_i1) <- 0:(nrow(irf_i1) - 1)
+    print(utils::head(irf_i1, n=N_to_print + 1))
+    cat("\n")
+  }
+
+  # If conf_ints not null: let know where conf_ints are found
+  if(!is.null(irf$conf_ints)) {
+    cat("Print confidence intervals from $conf_ints")
+  }
+  invisible(irf)
+}
